import os

from charmhelpers.core.templating import (
    ContextGenerator,
    RelationContext,
    StorableContext,
)


# Stores `config_data` hash into yaml file with `file_name` as a name
# if `file_name` already exists, then it loads data from `file_name`.
class StoredContext(ContextGenerator, StorableContext):
    def __init__(self, file_name, config_data):
        if os.path.exists(file_name):
            self.data = self.read_context(file_name)
        else:
            self.store_context(file_name, config_data)
            self.data = config_data

    def __call__(self):
        return self.data


class NatsContext(RelationContext):
    interface = 'nats'
    required_keys = ['nats_port', 'nats_address', 'nats_user', 'nats_password']


class MysqlDSNContext(RelationContext):
    interface = 'db'
    required_keys = ['user', 'password', 'host', 'database']
    dsn_template = "mysql2://{user}:{password}@{host}:{port}/{database}"

    def __call__(self):
        ctx = RelationContext.__call__(self)
        if ctx:
            if 'port' not in ctx:
                ctx['db']['port'] = '3306'
            ctx['db']['dsn'] = self.dsn_template.format(**ctx['db'])
        return ctx


class RouterContext(RelationContext):
    interface = 'router'
    required_keys = ['domain']


class LogRouterContext(RelationContext):
    interface = 'logrouter'
    required_keys = ['shared-secret', 'logrouter-address']


class LoggregatorContext(RelationContext):
    interface = 'loggregator'
    required_keys = ['shared_secret', 'loggregator_address']
