#!/usr/bin/env python
# vim: et ai ts=4 sw=4:
import os
import sys
import subprocess

from charmhelpers.core import host
from charmhelpers.core import hookenv
from charmhelpers.core.hookenv import log
from charmhelpers.core import services
from charmhelpers.contrib.cloudfoundry import contexts

import config

hooks = hookenv.Hooks()


def register():
    services.register([
        {
            'service': 'cf-cloudcontroller',
            'templates': [
                {'source': 'cf-cloudcontroller.conf'},
                {'source': 'cloud_controller.yml',
                 'target': config.CC_CONFIG_FILE,
                 'file_properties': {'owner': 'vcap'},
                 'contexts': [contexts.NatsContext(),
                              contexts.RouterContext(),
                              contexts.MysqlDSNContext()]}
            ],
            'complete': [db_migrate, host.service_restart],
        },
        {
            'service': 'cf-cloudcontroller-job',
            'templates': [{'source': 'cf-cloudcontroller-job.conf'}],
        },
    ])
    hooks.hook('config-changed',
               'db-relation-changed',
               'nats-relation-changed',
               'router-relation-changed')(services.reconfigure_services)
    hooks.hook('stop')(services.stop_services)


def db_migrate(service_name):
    hookenv.log("Starting db:migrate...", hookenv.DEBUG)
    with host.chdir(config.CC_DIR) as dir:
        subprocess.check_call([
            'sudo', '-u', 'vcap', '-g', 'vcap',
            'CLOUD_CONTROLLER_NG_CONFIG={}'.format(config.CC_CONFIG_FILE),
            'bundle', 'exec', 'rake', 'db:migrate'])
        hookenv.log("Finished db:migrate in %s." % (dir))


if __name__ == '__main__':
    register()
    hook_name = os.path.basename(sys.argv[0])
    log("Running {} hook".format(hook_name))
    if hookenv.relation_id():
        log("Relation {} with {}".format(
            hookenv.relation_id(), hookenv.remote_unit()))
    hooks.execute(sys.argv)
